# Import flask and template operators
from flask import Flask, render_template

# Define the WSGI application object
app = Flask(__name__, instance_relative_config=True)

# Configurations
app.config.from_object('config')
app.config.from_pyfile('config.py')

# Load the file specified by the APP_CONFIG_FILE environment variable
# Variables defined here will override those in the default configuration
# app.config.from_envvar('APP_CONFIG_FILE')

# Sample HTTP error handling
@app.errorhandler(404)
def not_found(error):
    return render_template('404.html'), 404

# Import a module / component using its blueprint handler variable (mod_auth)
from app.views.ft_frequent_hashtag import mod_ft_frequent_hashtag
from app.views.ft_frequent_topic import mod_ft_frequent_topic
from app.views.viewsentiment import mod_viewsentiment as viewsentiment_module
from app.views.viewsentiment import mod_ratiosentiment as ratiosentiment_module
from app.views.viewsentiment import mod_trendsentiment as trendsentiment_module
from app.views.popularity_entities import mod_stream_popularity_entities as popularity_entities_stream_module
from app.views.popularity_entities import mod_instance_popularity_entities as popularity_entities_instance_module
from app.views.instance_crawl import mod_twitter_instance_crawl as twitter_instance_crawl_module
from app.views.instance_crawl import mod_instagram_instance_crawl as instagram_instance_crawl_module
from app.views.instance_crawl import mod_kill_instance_crawl as kill_instance_crawl_module

# Register blueprint(s)
app.register_blueprint(mod_ft_frequent_hashtag)
app.register_blueprint(mod_ft_frequent_topic)
app.register_blueprint(viewsentiment_module)
app.register_blueprint(ratiosentiment_module)
app.register_blueprint(trendsentiment_module)
app.register_blueprint(popularity_entities_stream_module)
app.register_blueprint(popularity_entities_instance_module)
app.register_blueprint(twitter_instance_crawl_module)
app.register_blueprint(instagram_instance_crawl_module)
app.register_blueprint(kill_instance_crawl_module)