import json
import pymongo
import string
import re
import datetime

from app import app
from flask import Response, Blueprint, request, render_template
from collections import Counter
from heapq import nlargest
from operator import itemgetter

mod_ft_frequent_hashtag = Blueprint('ft_frequent_hashtag', __name__, url_prefix='/ft_frequent_hashtag/<collectionflag>')

@mod_ft_frequent_hashtag.route('', methods = ['GET'])
def ft_frequent_hashtag(collectionflag):
    myclient = pymongo.MongoClient()
    mydb = myclient["test_median_app"]
    mycol = mydb[collectionflag]
    
    hastags = list()
    links = list()
    for objx in mycol.find({}, {"_id": 0, "Hastag": 1}):
        for lstx in objx["Hastag"]:
            hastags.append("#"+lstx['text'].lower())
    
    hastagcount = Counter(hastags)
    hastagcountformat = list()
    for hastagitem in hastagcount:
        hastagcountformat.append({'text':hastagitem, 'size':int(hastagcount[hastagitem])*10})
        
    top10hastag = list()
    for text, size in nlargest(10, hastagcount.items(), key=itemgetter(1)):
        top10hastag.append(text)
        
    timeframe, hastagcountbydate, hastagtimelines = get_hashtag_timeline(top10hastag, collectionflag)
    
    js = json.dumps((timeframe, hastagtimelines, hastagcountbydate, hastagcountformat))
    resp = Response(js, status=200, mimetype='application/json')
    return resp

def get_hashtag_timeline(hastaglist, collectionflag):    
    myclient = pymongo.MongoClient()
    mydb = myclient["test_median_app"]
    mycol = mydb[collectionflag]
    
    hastagtimelines = list()
    datenow = datetime.datetime.now().strftime("%m/%d/%Y")
    datemin = "12/30/9999"
    for hastag in hastaglist:
        timelinelist = list()
        for objx in mycol.find({"TweetText": {"$regex":re.compile(r""+hastag+"(?i)")} }, {"_id":0,"TweetTime":1,"TweetText":1}):
            timelinelist.append(objx['TweetTime'].strftime("%m/%d/%Y"))
            if objx['TweetTime'] < datetime.datetime.strptime(datemin, "%m/%d/%Y"):
                datemin = objx['TweetTime'].strftime("%m/%d/%Y")
        hastagtimelines.append({'text':hastag, 'timelines':timelinelist})
    
    startdate = datetime.datetime.strptime(datemin, "%m/%d/%Y")
    daterange = [startdate + datetime.timedelta(days=x) for x in range(0, (datetime.datetime.now()-startdate).days)]
    
    datelist = list()
    for date in daterange:
        datelist.append(date.strftime("%m/%d/%Y"))
    
    hastagcounttimeline = list()
    for timeline in hastagtimelines:
        hastagcountbydate = list()
        for date in datelist:
            hastagcountbydate.append(timeline['timelines'].count(date))
        hastagcounttimeline.append({'name':timeline['text'], 'data':hastagcountbydate})
         
    return datelist, hastagcounttimeline, hastagtimelines