import networkx as nx
import json
import pymongo

from app import app
from flask import Response, Blueprint, request, render_template
from networkx.algorithms import community
from collections import Counter

mod_sc_network_thenets = Blueprint('sc_network_thenets', __name__, url_prefix='/sc_network_thenets/<collectionflag>')

@mod_sc_network_thenets.route('', methods = ['GET'])
def sc_network_thenets(collectionflag):
    myclient = pymongo.MongoClient("mongodb://localhost:27017/")
    mydb = myclient["test_median_app"]
    mycol = mydb["admin_20190914_ruu_kpk_streaming"]

    pairs = list()
    for item in mycol.find({}, {"_id": 0, "ScreenName": 1, "RetweetFrom": 1}):
        if item["RetweetFrom"]:
            pairs.append("%s > %s" % (item["ScreenName"], item["RetweetFrom"]))

    G = nx.Graph()
    edges = Counter(pairs)
    edgeList = list()
    for edge in edges:
        node = edge.split(' > ')
        edgeList.append((node[0], node[1], edges[edge]))
        G.add_edge(node[0], node[1], weight=edges[edge])

    communities_generator = community.girvan_newman(G)
    top_level_communities = next(communities_generator)
    next_level_communities = next(communities_generator)
    clusters = sorted(map(sorted, next_level_communities))

    group = 1
    nodeList = list()
    for cluster in clusters:
        for nodex in cluster:
            nodeList.append((nodex, group))
        group += 1 

    nodeListFormat = list()
    for nodeitem in nodeList:
        nodeListFormat.append({"id":nodeitem[0], "group":nodeitem[1]})
        
    edgeListFormat = list()
    for edgeitem in edgeList:
        edgeListFormat.append({"source":edgeitem[0], "target":edgeitem[1], "value":edgeitem[2]})
    
    js = json.dumps([nodeListFormat, edgeListFormat])
    resp = Response(js, status=200, mimetype='application/json')
    return resp