from pymongo import MongoClient, ASCENDING, DESCENDING
import functools
import operator
import collections
import random

class DBModel:

	# client = MongoClient("mongodb://172.16.14.19:27017/median")
	client = MongoClient()

	def get_data_all(self, database, collection):
		db = self.client[database]
		cursor = db[collection].find({})

		return cursor

	def insert_one(self, database, collection, documents):
		db = self.client[database]
		results = db[collection].insert(documents)

		return results

	def counting_data_one(self, database, collection, field, data):
		db = self.client[database]
		return db[collection].find({field:data}).count()

	def check_duplicate_key(self, database, collection, field, data):
		db = self.client[database]
		return db[collection].find({field:data}).count()

	def counting_repost(self, database, collection, field_x, field_y, data):
		""" menghitung jumlah repost dengan syarat Mention.screen_name dan RetweetFrom harus sesuai """
		db = self.client[database]
		count_repost = db[collection].find({"$and":[{field_x:data},{field_y:{"$ne":None}}]}).count() 
		return (1 if count_repost==0 else count_repost)

	def counting_mention(self, database, collection, field_x, data):
		""" menghitung jumlah mention dari sebuah akun yang dilakukan mention """
		db = self.client[database]
		count_mention = self.counting_data_one(database, collection, field_x, data)
		return (1 if count_mention==0 else count_mention)

	def count_of_tweet(self, database, collection, field_x, data):
		""" menghitung jumlah tweet secara unique dari sebuah akun yang dilakukan mention (yang membahas akun yang dilakukan mention)"""
		db = self.client[database]
		count_tweet = len(db[collection].distinct("TweetText",{field_x:data})) 
		return (1 if count_tweet==0 else count_tweet)

	def find_one(self, database, collection, data):
		db = self.client[database]
		return db[collection].find_one({"name":data})

	def findMostPopularTweet(self, database, collection, field_x, data):
		db = self.client[database]
		data = db[collection].find({field_x:data}).sort([("Count", DESCENDING)]).limit(1)
		result = {}
		for datum in data:
			result["TweetText"] = datum["TweetText"]
			result["Account"] = datum["Account"]
			result["Count"] = datum["Count"]
		return result

	def check_collection_exists(self, database, collection):
		db = self.client[database]
		list_collection = db.list_collection_names()
		
		if collection in list_collection:
			result = True
		else:
			result = False
		return result

	def update_count_unique_tweet(self, database, collection, tweet, akun):
		db = self.client[database]
		data = db[collection].find_one({"$and":[{"TweetText":tweet},{"Account":akun}]})
		update = db[collection].update(
				   { 
				   		"TweetText": tweet,
				   		"Account":akun
				   	},
				   {
				      "$set":{
							"Count":data["Count"]+1
				    }
				   }
				)
		return update

	def check_tweet_unique_exists(self, database, collection, tweet, akun):
		db = self.client[database]
		data = db[collection].find({"$and":[{"TweetText":tweet},{"Account":akun}]}).count()
		if data >= 1:
			result = True
		else:
			result = False
		return result

	def update_popularity(self, database, collection, account, data):
		db = self.client[database]
		update = db[collection].update(
				   { "account": account},
				   {
				      "$set":{
							"count_of_tweet":data["count_of_tweet"],
							"count_of_mention":data["count_of_mention"],
							"counting_retweet_from_mention":data["counting_retweet_from_mention"],
							"sum_of_mention_and_retweet_from_mention":data["sum_of_mention_and_retweet_from_mention"],
							"tweet":data["tweet"]
				      }
				   }
				)
		return update