# -*- coding: utf-8 -*-

# Define your item pipelines here
#
# Don't forget to add your pipeline to the ITEM_PIPELINES setting
# See: http://doc.scrapy.org/en/latest/topics/item-pipeline.html
import pymongo
from scrapy.conf import settings
from scrapy.exceptions import DropItem
import scrapycrawl.popularity_entities as pe
from scrapy import log

class TweetmobilePipeline(object):
	def __init__(self, mongo_uri, mongo_db):
		self.mongo_uri = mongo_uri
		self.mongo_db = mongo_db

	@classmethod	
	def from_crawler(cls, crawler):
		TweetmobilePipeline.ori = settings.get("collection")
		TweetmobilePipeline.database_name = settings.get("db")
		TweetmobilePipeline.name = "{}".format(TweetmobilePipeline.ori)
		return cls(
			mongo_uri=crawler.settings.get('MONGO_URI'),
			mongo_db=crawler.settings.get('MONGO_DATABASE', TweetmobilePipeline.database_name)
		)
	def open_spider(self, spider):
		self.client = pymongo.MongoClient(self.mongo_uri)
		self.db = self.client[self.mongo_db]

	def close_spider(self, spider):
		self.client.close()

	def check_data_exist(self, item):
		temp_exist = self.db[TweetmobilePipeline.name].find({"idTweet":item["idTweet"]}).count()
		exist = temp_exist > 0

		return exist

	def process_item(self, item, spider):
		valid = True
		if not item['TweetText']:
			valid = False
			raise DropItem("Missing {0}!".format(item))
		if valid and not self.check_data_exist(item):
			self.db[TweetmobilePipeline.name].insert(dict(item))
			data_dict = {}
			data_dict['index'] = item['index']
			data_dict['idTweet']  = item['idTweet'] 
			data_dict['idAccount'] = item['idAccount']
			data_dict['Username'] = item['Username']
			data_dict['Screenname'] = item['Screenname']
			data_dict['TweetText'] = item['TweetText']
			data_dict['TweetTextClean'] = item['TweetTextClean']
			data_dict['TweetTime'] = item['TweetTime']
			data_dict['LocationCoordinates'] = item['LocationCoordinates']
			data_dict['LocationPlace'] = item['LocationPlace']
			data_dict['Mention'] = item['Mention']
			data_dict['Hastag'] = item['Hastag']
			data_dict['Keyword'] = item['Keyword']
			data_dict['RelatedKeywords'] = item['RelatedKeywords']
			data_dict['Entities'] = item['Entities']
			data_dict['LinkContained'] = item['LinkContained']
			data_dict['RetweetFrom'] = item['RetweetFrom']
			data_dict['RetweetTweetID'] = item['RetweetTweetID']
			data_dict['TweetEnggagement'] = item['TweetEnggagement']
			data_dict['ReplyOfTweetScreenName'] = item['ReplyOfTweetScreenName']
			data_dict['ReplyOfTweetId'] = item['ReplyOfTweetId']
			data_dict['ReplyOfTweetText'] = item['ReplyOfTweetText']
			data_dict['Sentiment'] = item['Sentiment']
			data_dict['TweetUrl'] = item['TweetUrl']

			pe.popular_entity_instance(TweetmobilePipeline.database_name, TweetmobilePipeline.ori, data_dict)

			log.msg("data added to mongo database!",
                    level=log.DEBUG, spider=spider)
		else:
			log.msg("Data duplicate (not inserted)",
                    level=log.DEBUG, spider=spider)

		return item

class InstagramPipeline(object):
	collection_name = ""
	def __init__(self, mongo_uri, mongo_db):
		self.mongo_uri = mongo_uri
		self.mongo_db = mongo_db

	@classmethod	
	def from_crawler(cls, crawler):
		InstagramPipeline.ori = settings.get("collection")
		InstagramPipeline.database_name = settings.get("db")
		InstagramPipeline.collection_name = "{}_IG".format(InstagramPipeline.ori)
		return cls(
			mongo_uri=crawler.settings.get('MONGO_URI'),
			mongo_db=crawler.settings.get('MONGO_DATABASE', InstagramPipeline.database_name)
		)
	def open_spider(self, spider):
		self.client = pymongo.MongoClient(self.mongo_uri)
		self.db = self.client[self.mongo_db]

	def close_spider(self, spider):
		self.client.close()

	def check_data_exist(self, item):
		temp_exist = self.db[InstagramPipeline.collection_name].find({"idPost":item["idPost"]}).count()
		exist = temp_exist > 0

		return exist

	def process_item(self, item, spider):
		valid = True
		if not item['PostContent']:
			valid = False
			raise DropItem("Missing {0}!".format(item))
		if valid and not self.check_data_exist(item):
			self.db[InstagramPipeline.collection_name].insert(dict(item))
			log.msg("data added to mongo database!",
                    level=log.DEBUG, spider=spider)
		return item
